pub struct EffectBounds {
pub min: usize,
pub max: usize,
}Expand description
Limits for the maximum and minimum value that an effect may modify a statistic. The bounds are applied after the effect has been calculated to keep stats within a sane range.
min and max are inclusive.
Fields
min: usizemax: usizeTrait Implementations
Sourceimpl Add for EffectBounds
impl Add for EffectBounds
Sourceimpl Clone for EffectBounds
impl Clone for EffectBounds
Sourcefn clone(&self) -> EffectBounds
fn clone(&self) -> EffectBounds
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for EffectBounds
impl Debug for EffectBounds
Sourceimpl Default for EffectBounds
impl Default for EffectBounds
Sourcefn default() -> EffectBounds
fn default() -> EffectBounds
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for EffectBounds
impl<'de> Deserialize<'de> for EffectBounds
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl FromStr for EffectBounds
impl FromStr for EffectBounds
Sourcefn from_str(s: &str) -> Result<Self, Self::Err>
fn from_str(s: &str) -> Result<Self, Self::Err>
Parse an EffectBounds from a string.
Acceptable forms:
min:max- colon-separated valuesmin-max- dash-separated values
Errors are reported with EpochError::ParsingDurationError.
Sourcetype Err = EpochError
type Err = EpochError
The associated error which can be returned from parsing.
Sourceimpl Serialize for EffectBounds
impl Serialize for EffectBounds
Sourceimpl Sub for EffectBounds
impl Sub for EffectBounds